@@ -80,7 +80,7 @@ class _DataFrame:
 
         return pd.DataFrame(self.data)
 
-    def Synchronize(self, dataframe):
+    def Synchronize(self, dataframe, n_jobs=1):
         if not Auth.tokenValid():
             Auth.refreshToken()
 
@@ -583,7 +583,7 @@ class _DataFrame:
                 "data": ItemIDArray
             }        
                     
-            itemIDString = json.dump(x)
+            itemIDString = json.dumps(x)
 
             response = requests.delete(settings.baseURL + "api/item/" + self.app_id + "/" + self.collection_id +"/dataframe",
                         json={
